"""
All high level features of :class:`steam.client.SteamClient` are implemented here in separate submodules.
"""
from steam.client.builtins.misc import Misc
from steam.client.builtins.user import User
from steam.client.builtins.web import Web

class BuiltinBase(Misc, User, Web):
    """
    This object is used as base to implement all high level functionality.
    The features are separated into submodules.
    """
    pass



from steam.enums import EPersonaState
from steam.enums.emsg import EMsg
from steam.core.msg import MsgProto

class User(object):
    def __init__(self, *args, **kwargs):
        super(User, self).__init__(*args, **kwargs)

    def set_persona(self, state=None, name=None):
        """
        Set persona state and/or name

        :param state: persona state flag
        :type state: :class:`steam.enums.common.EPersonaState`
        :param name: profile name
        :type name: :class:`str`
        """
        if state is None and name is None:
            return

        message = MsgProto(EMsg.ClientChangeStatus)

        if state:
            if not isinstance(state, EPersonaState):
                raise ValueError("Expected state to be instance of EPersonaState")

            message.body.persona_state = state

        if name:
            message.body.player_name = name

        self.send(message)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_inventory.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_inventory.proto',
  package='',
  syntax='proto2',
  serialized_pb=b'\n\x1dsteammessages_inventory.proto\x1a steammessages_unified_base.proto\"A\n\x1f\x43Inventory_GetInventory_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"t\n\x13\x43Inventory_Response\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x16\n\x0eremoveditemids\x18\x02 \x03(\x04\x12\x11\n\titem_json\x18\x03 \x01(\t\x12\x14\n\x0citemdef_json\x18\x04 \x01(\t\x12\x0e\n\x06ticket\x18\x05 \x01(\x0c\"\x8e\x01\n\x1f\x43Inventory_ExchangeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0fmaterialsitemid\x18\x03 \x03(\x04\x12\x19\n\x11materialsquantity\x18\x04 \x03(\r\x12\x17\n\x0foutputitemdefid\x18\x05 \x01(\x04\"f\n\x1a\x43Inventory_AddItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x03(\x04\x12\x15\n\ritempropsjson\x18\x03 \x03(\t\x12\x0f\n\x07steamid\x18\x04 \x01(\x04\"i\n!CInventory_SafeModifyItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63\x63tid\x18\x02 \x01(\x04\x12\x0e\n\x06itemid\x18\x03 \x01(\x04\x12\x15\n\ritempropsjson\x18\x04 \x01(\t\"F\n\"CInventory_ConsumePlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\"\xdb\x01\n\x1e\x43Inventory_GetItemDefs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x15\n\rmodifiedsince\x18\x02 \x01(\t\x12\x12\n\nitemdefids\x18\x04 \x03(\x04\x12\x13\n\x0bworkshopids\x18\x05 \x03(\x04\x12j\n\x15\x63\x61\x63he_max_age_seconds\x18\x07 \x01(\r:\x01\x30\x42H\x82\xb5\x18\x44\x41llow stale data to be returned for the specified number of seconds.\"d\n\x1e\x43Inventory_ConsumeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\t\"W\n!CInventory_DevSetNextDrop_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\x12\x10\n\x08\x64roptime\x18\x03 \x01(\t\"g\n!CInventory_SplitItemStack_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\t\"\x9d\x01\n$CInventory_CombineItemStacks_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nfromitemid\x18\x02 \x01(\x04\x12\x12\n\ndestitemid\x18\x03 \x01(\x04\x12\x10\n\x08quantity\x18\x04 \x01(\r\x12\x15\n\rfromtimestamp\x18\x05 \x01(\t\x12\x15\n\rdesttimestamp\x18\x06 \x01(\t2\xa5\n\n\tInventory\x12z\n\x0cGetInventory\x12 .CInventory_GetInventory_Request\x1a\x14.CInventory_Response\"2\x82\xb5\x18.Retrieves a users inventory as a big JSON blob\x12o\n\x0c\x45xchangeItem\x12 .CInventory_ExchangeItem_Request\x1a\x14.CInventory_Response\"\'\x82\xb5\x18#Craft an item in a user\'s inventory\x12n\n\x0c\x41\x64\x64PromoItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\"+\x82\xb5\x18\'Adds a promo item to a user\'s inventory\x12\x8b\x01\n\x0eSafeModifyItem\x12\".CInventory_SafeModifyItem_Request\x1a\x14.CInventory_Response\"?\x82\xb5\x18;Modify an item in a user\'s inventory (safe properties only)\x12\x87\x01\n\x0f\x43onsumePlaytime\x12#.CInventory_ConsumePlaytime_Request\x1a\x14.CInventory_Response\"9\x82\xb5\x18\x35\x43onsumes playtime and possibly returns a granted item\x12^\n\x0bGetItemDefs\x12\x1f.CInventory_GetItemDefs_Request\x1a\x14.CInventory_Response\"\x18\x82\xb5\x18\x14Get item definitions\x12Y\n\x0b\x43onsumeItem\x12\x1f.CInventory_ConsumeItem_Request\x1a\x14.CInventory_Response\"\x13\x82\xb5\x18\x0f\x43onsume an item\x12n\n\x0f\x44\x65vGenerateItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\"(\x82\xb5\x18$Grant an item when in developer mode\x12_\n\x0e\x44\x65vSetNextDrop\x12\".CInventory_DevSetNextDrop_Request\x1a\x14.CInventory_Response\"\x13\x82\xb5\x18\x0f\x43onsume an item\x12s\n\x0eSplitItemStack\x12\".CInventory_SplitItemStack_Request\x1a\x14.CInventory_Response\"\'\x82\xb5\x18#Split an item stack into two stacks\x12q\n\x11\x43ombineItemStacks\x12%.CInventory_CombineItemStacks_Request\x1a\x14.CInventory_Response\"\x1f\x82\xb5\x18\x1b\x43ombine two stacks of items\x1a/\x82\xb5\x18+A service that provides access to inventoryB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CINVENTORY_GETINVENTORY_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetInventory_Request',
  full_name='CInventory_GetInventory_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_GetInventory_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_GetInventory_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=132,
)


_CINVENTORY_RESPONSE = _descriptor.Descriptor(
  name='CInventory_Response',
  full_name='CInventory_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='etag', full_name='CInventory_Response.etag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='removeditemids', full_name='CInventory_Response.removeditemids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_json', full_name='CInventory_Response.item_json', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdef_json', full_name='CInventory_Response.itemdef_json', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CInventory_Response.ticket', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=250,
)


_CINVENTORY_EXCHANGEITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_ExchangeItem_Request',
  full_name='CInventory_ExchangeItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ExchangeItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_ExchangeItem_Request.steamid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='materialsitemid', full_name='CInventory_ExchangeItem_Request.materialsitemid', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='materialsquantity', full_name='CInventory_ExchangeItem_Request.materialsquantity', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outputitemdefid', full_name='CInventory_ExchangeItem_Request.outputitemdefid', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=395,
)


_CINVENTORY_ADDITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_AddItem_Request',
  full_name='CInventory_AddItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_AddItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_AddItem_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itempropsjson', full_name='CInventory_AddItem_Request.itempropsjson', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CInventory_AddItem_Request.steamid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=499,
)


_CINVENTORY_SAFEMODIFYITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_SafeModifyItem_Request',
  full_name='CInventory_SafeModifyItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_SafeModifyItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acctid', full_name='CInventory_SafeModifyItem_Request.acctid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_SafeModifyItem_Request.itemid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itempropsjson', full_name='CInventory_SafeModifyItem_Request.itempropsjson', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=606,
)


_CINVENTORY_CONSUMEPLAYTIME_REQUEST = _descriptor.Descriptor(
  name='CInventory_ConsumePlaytime_Request',
  full_name='CInventory_ConsumePlaytime_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ConsumePlaytime_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_ConsumePlaytime_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=678,
)


_CINVENTORY_GETITEMDEFS_REQUEST = _descriptor.Descriptor(
  name='CInventory_GetItemDefs_Request',
  full_name='CInventory_GetItemDefs_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_GetItemDefs_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modifiedsince', full_name='CInventory_GetItemDefs_Request.modifiedsince', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdefids', full_name='CInventory_GetItemDefs_Request.itemdefids', index=2,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='workshopids', full_name='CInventory_GetItemDefs_Request.workshopids', index=3,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cache_max_age_seconds', full_name='CInventory_GetItemDefs_Request.cache_max_age_seconds', index=4,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\202\265\030DAllow stale data to be returned for the specified number of seconds.')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=900,
)


_CINVENTORY_CONSUMEITEM_REQUEST = _descriptor.Descriptor(
  name='CInventory_ConsumeItem_Request',
  full_name='CInventory_ConsumeItem_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_ConsumeItem_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_ConsumeItem_Request.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_ConsumeItem_Request.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CInventory_ConsumeItem_Request.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=1002,
)


_CINVENTORY_DEVSETNEXTDROP_REQUEST = _descriptor.Descriptor(
  name='CInventory_DevSetNextDrop_Request',
  full_name='CInventory_DevSetNextDrop_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_DevSetNextDrop_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemdefid', full_name='CInventory_DevSetNextDrop_Request.itemdefid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='droptime', full_name='CInventory_DevSetNextDrop_Request.droptime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1091,
)


_CINVENTORY_SPLITITEMSTACK_REQUEST = _descriptor.Descriptor(
  name='CInventory_SplitItemStack_Request',
  full_name='CInventory_SplitItemStack_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_SplitItemStack_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='itemid', full_name='CInventory_SplitItemStack_Request.itemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_SplitItemStack_Request.quantity', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CInventory_SplitItemStack_Request.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1196,
)


_CINVENTORY_COMBINEITEMSTACKS_REQUEST = _descriptor.Descriptor(
  name='CInventory_CombineItemStacks_Request',
  full_name='CInventory_CombineItemStacks_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CInventory_CombineItemStacks_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromitemid', full_name='CInventory_CombineItemStacks_Request.fromitemid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destitemid', full_name='CInventory_CombineItemStacks_Request.destitemid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CInventory_CombineItemStacks_Request.quantity', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromtimestamp', full_name='CInventory_CombineItemStacks_Request.fromtimestamp', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desttimestamp', full_name='CInventory_CombineItemStacks_Request.desttimestamp', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1356,
)

DESCRIPTOR.message_types_by_name['CInventory_GetInventory_Request'] = _CINVENTORY_GETINVENTORY_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_Response'] = _CINVENTORY_RESPONSE
DESCRIPTOR.message_types_by_name['CInventory_ExchangeItem_Request'] = _CINVENTORY_EXCHANGEITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_AddItem_Request'] = _CINVENTORY_ADDITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_SafeModifyItem_Request'] = _CINVENTORY_SAFEMODIFYITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_ConsumePlaytime_Request'] = _CINVENTORY_CONSUMEPLAYTIME_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_GetItemDefs_Request'] = _CINVENTORY_GETITEMDEFS_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_ConsumeItem_Request'] = _CINVENTORY_CONSUMEITEM_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_DevSetNextDrop_Request'] = _CINVENTORY_DEVSETNEXTDROP_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_SplitItemStack_Request'] = _CINVENTORY_SPLITITEMSTACK_REQUEST
DESCRIPTOR.message_types_by_name['CInventory_CombineItemStacks_Request'] = _CINVENTORY_COMBINEITEMSTACKS_REQUEST

CInventory_GetInventory_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetInventory_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_GETINVENTORY_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetInventory_Request)
  ))
_sym_db.RegisterMessage(CInventory_GetInventory_Request)

CInventory_Response = _reflection.GeneratedProtocolMessageType('CInventory_Response', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_RESPONSE,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_Response)
  ))
_sym_db.RegisterMessage(CInventory_Response)

CInventory_ExchangeItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_ExchangeItem_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_EXCHANGEITEM_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ExchangeItem_Request)
  ))
_sym_db.RegisterMessage(CInventory_ExchangeItem_Request)

CInventory_AddItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_AddItem_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_ADDITEM_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_AddItem_Request)
  ))
_sym_db.RegisterMessage(CInventory_AddItem_Request)

CInventory_SafeModifyItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_SafeModifyItem_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_SAFEMODIFYITEM_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_SafeModifyItem_Request)
  ))
_sym_db.RegisterMessage(CInventory_SafeModifyItem_Request)

CInventory_ConsumePlaytime_Request = _reflection.GeneratedProtocolMessageType('CInventory_ConsumePlaytime_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_CONSUMEPLAYTIME_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ConsumePlaytime_Request)
  ))
_sym_db.RegisterMessage(CInventory_ConsumePlaytime_Request)

CInventory_GetItemDefs_Request = _reflection.GeneratedProtocolMessageType('CInventory_GetItemDefs_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_GETITEMDEFS_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_GetItemDefs_Request)
  ))
_sym_db.RegisterMessage(CInventory_GetItemDefs_Request)

CInventory_ConsumeItem_Request = _reflection.GeneratedProtocolMessageType('CInventory_ConsumeItem_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_CONSUMEITEM_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_ConsumeItem_Request)
  ))
_sym_db.RegisterMessage(CInventory_ConsumeItem_Request)

CInventory_DevSetNextDrop_Request = _reflection.GeneratedProtocolMessageType('CInventory_DevSetNextDrop_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_DEVSETNEXTDROP_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_DevSetNextDrop_Request)
  ))
_sym_db.RegisterMessage(CInventory_DevSetNextDrop_Request)

CInventory_SplitItemStack_Request = _reflection.GeneratedProtocolMessageType('CInventory_SplitItemStack_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_SPLITITEMSTACK_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_SplitItemStack_Request)
  ))
_sym_db.RegisterMessage(CInventory_SplitItemStack_Request)

CInventory_CombineItemStacks_Request = _reflection.GeneratedProtocolMessageType('CInventory_CombineItemStacks_Request', (_message.Message,), dict(
  DESCRIPTOR = _CINVENTORY_COMBINEITEMSTACKS_REQUEST,
  __module__ = 'steammessages_inventory_pb2'
  # @@protoc_insertion_point(class_scope:CInventory_CombineItemStacks_Request)
  ))
_sym_db.RegisterMessage(CInventory_CombineItemStacks_Request)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), b'\220\001\001')
_CINVENTORY_GETITEMDEFS_REQUEST.fields_by_name['cache_max_age_seconds'].has_options = True
_CINVENTORY_GETITEMDEFS_REQUEST.fields_by_name['cache_max_age_seconds']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), b'\202\265\030DAllow stale data to be returned for the specified number of seconds.')

_INVENTORY = _descriptor.ServiceDescriptor(
  name='Inventory',
  full_name='Inventory',
  file=DESCRIPTOR,
  index=0,
  options=_descriptor._ParseOptions(descriptor_pb2.ServiceOptions(), b'\202\265\030+A service that provides access to inventory'),
  serialized_start=1359,
  serialized_end=2676,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInventory',
    full_name='Inventory.GetInventory',
    index=0,
    containing_service=None,
    input_type=_CINVENTORY_GETINVENTORY_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030.Retrieves a users inventory as a big JSON blob'),
  ),
  _descriptor.MethodDescriptor(
    name='ExchangeItem',
    full_name='Inventory.ExchangeItem',
    index=1,
    containing_service=None,
    input_type=_CINVENTORY_EXCHANGEITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030#Craft an item in a user\'s inventory'),
  ),
  _descriptor.MethodDescriptor(
    name='AddPromoItem',
    full_name='Inventory.AddPromoItem',
    index=2,
    containing_service=None,
    input_type=_CINVENTORY_ADDITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\'Adds a promo item to a user\'s inventory'),
  ),
  _descriptor.MethodDescriptor(
    name='SafeModifyItem',
    full_name='Inventory.SafeModifyItem',
    index=3,
    containing_service=None,
    input_type=_CINVENTORY_SAFEMODIFYITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030;Modify an item in a user\'s inventory (safe properties only)'),
  ),
  _descriptor.MethodDescriptor(
    name='ConsumePlaytime',
    full_name='Inventory.ConsumePlaytime',
    index=4,
    containing_service=None,
    input_type=_CINVENTORY_CONSUMEPLAYTIME_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\0305Consumes playtime and possibly returns a granted item'),
  ),
  _descriptor.MethodDescriptor(
    name='GetItemDefs',
    full_name='Inventory.GetItemDefs',
    index=5,
    containing_service=None,
    input_type=_CINVENTORY_GETITEMDEFS_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\024Get item definitions'),
  ),
  _descriptor.MethodDescriptor(
    name='ConsumeItem',
    full_name='Inventory.ConsumeItem',
    index=6,
    containing_service=None,
    input_type=_CINVENTORY_CONSUMEITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\017Consume an item'),
  ),
  _descriptor.MethodDescriptor(
    name='DevGenerateItem',
    full_name='Inventory.DevGenerateItem',
    index=7,
    containing_service=None,
    input_type=_CINVENTORY_ADDITEM_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030$Grant an item when in developer mode'),
  ),
  _descriptor.MethodDescriptor(
    name='DevSetNextDrop',
    full_name='Inventory.DevSetNextDrop',
    index=8,
    containing_service=None,
    input_type=_CINVENTORY_DEVSETNEXTDROP_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\017Consume an item'),
  ),
  _descriptor.MethodDescriptor(
    name='SplitItemStack',
    full_name='Inventory.SplitItemStack',
    index=9,
    containing_service=None,
    input_type=_CINVENTORY_SPLITITEMSTACK_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030#Split an item stack into two stacks'),
  ),
  _descriptor.MethodDescriptor(
    name='CombineItemStacks',
    full_name='Inventory.CombineItemStacks',
    index=10,
    containing_service=None,
    input_type=_CINVENTORY_COMBINEITEMSTACKS_REQUEST,
    output_type=_CINVENTORY_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\033Combine two stacks of items'),
  ),
])

Inventory = service_reflection.GeneratedServiceType('Inventory', (_service.Service,), dict(
  DESCRIPTOR = _INVENTORY,
  __module__ = 'steammessages_inventory_pb2'
  ))

Inventory_Stub = service_reflection.GeneratedServiceStubType('Inventory_Stub', (Inventory,), dict(
  DESCRIPTOR = _INVENTORY,
  __module__ = 'steammessages_inventory_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_base.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_base.proto',
  package='',
  syntax='proto2',
  serialized_pb=b'\n\x18steammessages_base.proto\x1a google/protobuf/descriptor.proto\"\xf8\x03\n\x12\x43MsgProtoBufHeader\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10\x63lient_sessionid\x18\x02 \x01(\x05\x12\x15\n\rrouting_appid\x18\x03 \x01(\r\x12*\n\x0cjobid_source\x18\n \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12*\n\x0cjobid_target\x18\x0b \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x17\n\x0ftarget_job_name\x18\x0c \x01(\t\x12\x0f\n\x07seq_num\x18\x18 \x01(\x05\x12\x12\n\x07\x65result\x18\r \x01(\x05:\x01\x32\x12\x15\n\rerror_message\x18\x0e \x01(\t\x12\n\n\x02ip\x18\x0f \x01(\r\x12\x1a\n\x12\x61uth_account_flags\x18\x10 \x01(\r\x12\x14\n\x0ctoken_source\x18\x16 \x01(\r\x12\x1b\n\x13\x61\x64min_spoofing_user\x18\x17 \x01(\x08\x12\x1a\n\x0ftransport_error\x18\x11 \x01(\x05:\x01\x31\x12\'\n\tmessageid\x18\x12 \x01(\x04:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x1a\n\x12publisher_group_id\x18\x13 \x01(\r\x12\r\n\x05sysid\x18\x14 \x01(\r\x12\x11\n\ttrace_tag\x18\x15 \x01(\x04\x12\x15\n\rwebapi_key_id\x18\x19 \x01(\r\"8\n\tCMsgMulti\x12\x15\n\rsize_unzipped\x18\x01 \x01(\r\x12\x14\n\x0cmessage_body\x18\x02 \x01(\x0c\"+\n\x13\x43MsgProtobufWrapped\x12\x14\n\x0cmessage_body\x18\x01 \x01(\x0c\"\x8f\x01\n\x0e\x43MsgAuthTicket\x12\x0e\n\x06\x65state\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x06\x12\x14\n\x0ch_steam_pipe\x18\x05 \x01(\r\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x0e\n\x06ticket\x18\x07 \x01(\x0c\"\xf6\x01\n\x14\x43\x43\x44\x44\x42\x41ppDetailCommon\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x12\n\nlogo_small\x18\x05 \x01(\t\x12\x0c\n\x04tool\x18\x06 \x01(\x08\x12\x0c\n\x04\x64\x65mo\x18\x07 \x01(\x08\x12\r\n\x05media\x18\x08 \x01(\x08\x12\x1f\n\x17\x63ommunity_visible_stats\x18\t \x01(\x08\x12\x15\n\rfriendly_name\x18\n \x01(\t\x12\x13\n\x0bpropagation\x18\x0b \x01(\t\x12\x19\n\x11has_adult_content\x18\x0c \x01(\x08\"\xef\x02\n\rCMsgAppRights\x12\x11\n\tedit_info\x18\x01 \x01(\x08\x12\x0f\n\x07publish\x18\x02 \x01(\x08\x12\x17\n\x0fview_error_data\x18\x03 \x01(\x08\x12\x10\n\x08\x64ownload\x18\x04 \x01(\x08\x12\x15\n\rupload_cdkeys\x18\x05 \x01(\x08\x12\x17\n\x0fgenerate_cdkeys\x18\x06 \x01(\x08\x12\x17\n\x0fview_financials\x18\x07 \x01(\x08\x12\x12\n\nmanage_ceg\x18\x08 \x01(\x08\x12\x16\n\x0emanage_signing\x18\t \x01(\x08\x12\x15\n\rmanage_cdkeys\x18\n \x01(\x08\x12\x16\n\x0e\x65\x64it_marketing\x18\x0b \x01(\x08\x12\x17\n\x0f\x65\x63onomy_support\x18\x0c \x01(\x08\x12\"\n\x1a\x65\x63onomy_support_supervisor\x18\r \x01(\x08\x12\x16\n\x0emanage_pricing\x18\x0e \x01(\x08\x12\x16\n\x0e\x62roadcast_live\x18\x0f \x01(\x08:A\n\x12msgpool_soft_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\x05:\x02\x33\x32:B\n\x12msgpool_hard_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd1\x86\x03 \x01(\x05:\x03\x33\x38\x34:C\n\x14\x66orce_php_generation\x12\x1c.google.protobuf.FileOptions\x18\xd0\x86\x03 \x01(\x08:\x05\x66\x61lseB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


MSGPOOL_SOFT_LIMIT_FIELD_NUMBER = 50000
msgpool_soft_limit = _descriptor.FieldDescriptor(
  name='msgpool_soft_limit', full_name='msgpool_soft_limit', index=0,
  number=50000, type=5, cpp_type=1, label=1,
  has_default_value=True, default_value=32,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)
MSGPOOL_HARD_LIMIT_FIELD_NUMBER = 50001
msgpool_hard_limit = _descriptor.FieldDescriptor(
  name='msgpool_hard_limit', full_name='msgpool_hard_limit', index=1,
  number=50001, type=5, cpp_type=1, label=1,
  has_default_value=True, default_value=384,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)
FORCE_PHP_GENERATION_FIELD_NUMBER = 50000
force_php_generation = _descriptor.FieldDescriptor(
  name='force_php_generation', full_name='force_php_generation', index=2,
  number=50000, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)


_CMSGPROTOBUFHEADER = _descriptor.Descriptor(
  name='CMsgProtoBufHeader',
  full_name='CMsgProtoBufHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgProtoBufHeader.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_sessionid', full_name='CMsgProtoBufHeader.client_sessionid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='routing_appid', full_name='CMsgProtoBufHeader.routing_appid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jobid_source', full_name='CMsgProtoBufHeader.jobid_source', index=3,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jobid_target', full_name='CMsgProtoBufHeader.jobid_target', index=4,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_job_name', full_name='CMsgProtoBufHeader.target_job_name', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='CMsgProtoBufHeader.seq_num', index=6,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgProtoBufHeader.eresult', index=7,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='CMsgProtoBufHeader.error_message', index=8,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgProtoBufHeader.ip', index=9,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auth_account_flags', full_name='CMsgProtoBufHeader.auth_account_flags', index=10,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token_source', full_name='CMsgProtoBufHeader.token_source', index=11,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='admin_spoofing_user', full_name='CMsgProtoBufHeader.admin_spoofing_user', index=12,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transport_error', full_name='CMsgProtoBufHeader.transport_error', index=13,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='messageid', full_name='CMsgProtoBufHeader.messageid', index=14,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='publisher_group_id', full_name='CMsgProtoBufHeader.publisher_group_id', index=15,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sysid', full_name='CMsgProtoBufHeader.sysid', index=16,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trace_tag', full_name='CMsgProtoBufHeader.trace_tag', index=17,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='webapi_key_id', full_name='CMsgProtoBufHeader.webapi_key_id', index=18,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=567,
)


_CMSGMULTI = _descriptor.Descriptor(
  name='CMsgMulti',
  full_name='CMsgMulti',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_unzipped', full_name='CMsgMulti.size_unzipped', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_body', full_name='CMsgMulti.message_body', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=625,
)


_CMSGPROTOBUFWRAPPED = _descriptor.Descriptor(
  name='CMsgProtobufWrapped',
  full_name='CMsgProtobufWrapped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_body', full_name='CMsgProtobufWrapped.message_body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=670,
)


_CMSGAUTHTICKET = _descriptor.Descriptor(
  name='CMsgAuthTicket',
  full_name='CMsgAuthTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='estate', full_name='CMsgAuthTicket.estate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgAuthTicket.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CMsgAuthTicket.steamid', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CMsgAuthTicket.gameid', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='h_steam_pipe', full_name='CMsgAuthTicket.h_steam_pipe', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket_crc', full_name='CMsgAuthTicket.ticket_crc', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ticket', full_name='CMsgAuthTicket.ticket', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=816,
)


_CCDDBAPPDETAILCOMMON = _descriptor.Descriptor(
  name='CCDDBAppDetailCommon',
  full_name='CCDDBAppDetailCommon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CCDDBAppDetailCommon.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CCDDBAppDetailCommon.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='icon', full_name='CCDDBAppDetailCommon.icon', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CCDDBAppDetailCommon.logo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo_small', full_name='CCDDBAppDetailCommon.logo_small', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool', full_name='CCDDBAppDetailCommon.tool', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='demo', full_name='CCDDBAppDetailCommon.demo', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='media', full_name='CCDDBAppDetailCommon.media', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='community_visible_stats', full_name='CCDDBAppDetailCommon.community_visible_stats', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendly_name', full_name='CCDDBAppDetailCommon.friendly_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='propagation', full_name='CCDDBAppDetailCommon.propagation', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_adult_content', full_name='CCDDBAppDetailCommon.has_adult_content', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=1065,
)


_CMSGAPPRIGHTS = _descriptor.Descriptor(
  name='CMsgAppRights',
  full_name='CMsgAppRights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edit_info', full_name='CMsgAppRights.edit_info', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='publish', full_name='CMsgAppRights.publish', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_error_data', full_name='CMsgAppRights.view_error_data', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='download', full_name='CMsgAppRights.download', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_cdkeys', full_name='CMsgAppRights.upload_cdkeys', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='generate_cdkeys', full_name='CMsgAppRights.generate_cdkeys', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_financials', full_name='CMsgAppRights.view_financials', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manage_ceg', full_name='CMsgAppRights.manage_ceg', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manage_signing', full_name='CMsgAppRights.manage_signing', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manage_cdkeys', full_name='CMsgAppRights.manage_cdkeys', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edit_marketing', full_name='CMsgAppRights.edit_marketing', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='economy_support', full_name='CMsgAppRights.economy_support', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='economy_support_supervisor', full_name='CMsgAppRights.economy_support_supervisor', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='manage_pricing', full_name='CMsgAppRights.manage_pricing', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_live', full_name='CMsgAppRights.broadcast_live', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1435,
)

DESCRIPTOR.message_types_by_name['CMsgProtoBufHeader'] = _CMSGPROTOBUFHEADER
DESCRIPTOR.message_types_by_name['CMsgMulti'] = _CMSGMULTI
DESCRIPTOR.message_types_by_name['CMsgProtobufWrapped'] = _CMSGPROTOBUFWRAPPED
DESCRIPTOR.message_types_by_name['CMsgAuthTicket'] = _CMSGAUTHTICKET
DESCRIPTOR.message_types_by_name['CCDDBAppDetailCommon'] = _CCDDBAPPDETAILCOMMON
DESCRIPTOR.message_types_by_name['CMsgAppRights'] = _CMSGAPPRIGHTS
DESCRIPTOR.extensions_by_name['msgpool_soft_limit'] = msgpool_soft_limit
DESCRIPTOR.extensions_by_name['msgpool_hard_limit'] = msgpool_hard_limit
DESCRIPTOR.extensions_by_name['force_php_generation'] = force_php_generation

CMsgProtoBufHeader = _reflection.GeneratedProtocolMessageType('CMsgProtoBufHeader', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPROTOBUFHEADER,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CMsgProtoBufHeader)
  ))
_sym_db.RegisterMessage(CMsgProtoBufHeader)

CMsgMulti = _reflection.GeneratedProtocolMessageType('CMsgMulti', (_message.Message,), dict(
  DESCRIPTOR = _CMSGMULTI,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CMsgMulti)
  ))
_sym_db.RegisterMessage(CMsgMulti)

CMsgProtobufWrapped = _reflection.GeneratedProtocolMessageType('CMsgProtobufWrapped', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPROTOBUFWRAPPED,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CMsgProtobufWrapped)
  ))
_sym_db.RegisterMessage(CMsgProtobufWrapped)

CMsgAuthTicket = _reflection.GeneratedProtocolMessageType('CMsgAuthTicket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAUTHTICKET,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAuthTicket)
  ))
_sym_db.RegisterMessage(CMsgAuthTicket)

CCDDBAppDetailCommon = _reflection.GeneratedProtocolMessageType('CCDDBAppDetailCommon', (_message.Message,), dict(
  DESCRIPTOR = _CCDDBAPPDETAILCOMMON,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CCDDBAppDetailCommon)
  ))
_sym_db.RegisterMessage(CCDDBAppDetailCommon)

CMsgAppRights = _reflection.GeneratedProtocolMessageType('CMsgAppRights', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPRIGHTS,
  __module__ = 'steammessages_base_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAppRights)
  ))
_sym_db.RegisterMessage(CMsgAppRights)

google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msgpool_soft_limit)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msgpool_hard_limit)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(force_php_generation)

DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), b'H\001\220\001\000')
# @@protoc_insertion_point(module_scope)
